==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/jca/src/javax/resource/spi/InvalidPropertyException.java <==
/*
 * Copyright (c) 1998-2003 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package javax.resource.spi;

import javax.resource.ResourceException;

/**
 * An exception with internal causes.
 */
public class InvalidPropertyException extends ResourceException {
  public InvalidPropertyException()
  {
  }

  public InvalidPropertyException(String reason)
  {
    super(reason);
  }

  public InvalidPropertyException(String reason, String errorCode)
  {
    super(reason, errorCode);
  }

  public InvalidPropertyException(String reason, Throwable e)
  {
    super(reason, e);
  }

  public InvalidPropertyException(Throwable e)
  {
    super(e);
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/jca/src/javax/resource/spi/InvalidPropertyException.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package javax.resource.spi;

import javax.resource.ResourceException;
import java.beans.PropertyDescriptor;

/**
 * An exception with internal causes.
 */
public class InvalidPropertyException
  extends ResourceException
{
  private PropertyDescriptor[] _invalidProperties;

  public InvalidPropertyException()
  {
  }

  public InvalidPropertyException(String reason)
  {
    super(reason);
  }

  public InvalidPropertyException(String reason, String errorCode)
  {
    super(reason, errorCode);
  }

  public InvalidPropertyException(String reason, Throwable e)
  {
    super(reason, e);
  }

  public InvalidPropertyException(Throwable e)
  {
    super(e);
  }

  public void setInvalidPropertyDescriptors(PropertyDescriptor[] invalidProperties)
  {
    _invalidProperties = invalidProperties;
  }

  public PropertyDescriptor[] getInvalidPropertyDescriptors()
  {
    return _invalidProperties;
  }
}
